#
# spec file for package HANA-Firewall
#
# Copyright (c) 2015-2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2022 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           HANA-Firewall
Version:        2.0.4
Release:        150000.3.9.3
License:        GPL-2.0+
Summary:        Generate firewalld service definitions for SAP HANA
Url:            https://github.com/SUSE/HANA-Firewall
Group:          Productivity/Networking/Security
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  go
BuildRequires:  yast2
BuildRequires:  yast2-devtools
Requires:       firewalld
ExclusiveArch:  x86_64 ppc64le
%{?systemd_requires}

%define GONS github.com/SUSE
%define SRCDIR  src/%{GONS}/%{name}

%description
This is a firewall utility that takes HANA instance numbers and HANA network service
definitions as input, and generates firewalld service definitions in XML format.

%prep
mkdir -p %{SRCDIR}
cd %{SRCDIR}
tar xf %{S:0}

%check
export GOPATH=$(pwd)
export GO111MODULE=off
cd %{SRCDIR}
go test -cover -v ./...

%build
export GOPATH=$(pwd)
export GO111MODULE=off
cd %{SRCDIR}
gzip ospackage/hana-firewall.8
go build -o hana-firewall

%install
cd %{SRCDIR}
mkdir -p %{buildroot}/%{_sbindir}
install -m 0755 hana-firewall %{buildroot}/%{_sbindir}/

# One manual page
mkdir -p %{buildroot}/%{_mandir}/man8
install -m 0644 ospackage/hana-firewall.8.gz %{buildroot}/%{_mandir}/man8/

# One sysconfig file
mkdir -p %{buildroot}/%{_fillupdir}/
install -m 0644 ospackage/sysconfig.hana-firewall %{buildroot}/%{_fillupdir}/sysconfig.hana-firewall

# Several service definition files
mkdir -p %{buildroot}/%{_sysconfdir}/hana-firewall
pushd ospackage/hana-firewall
for file in *; do
    install -m 0600 "$file" %{buildroot}/%{_sysconfdir}/hana-firewall/
done
popd

#Yast2 scrconf file
mkdir -p %{buildroot}%{yast_dir}/scrconf
install -m 0644 ospackage/hana-firewall.scr %{buildroot}%{yast_dir}/scrconf
%post
%fillup_only -n hana-firewall

%files
%defattr(-,root,root)
%config %{_sysconfdir}/hana-firewall/
%{_sbindir}/hana-firewall
%{_mandir}/man8/hana-firewall.8.gz
%{_fillupdir}/sysconfig.hana-firewall
%{yast_dir}/scrconf/hana-firewall.scr

%changelog
* Tue May  7 2024 varkoly@suse.com
- HANA-Firewall creates insufficient configuration.
  (bsc#1221231)
* Tue May  2 2023 varkoly@suse.com
- Missing SCR Agent for reading and writing /etc/sysconfig/hana-firewall from yast2
  (bsc#1210981)
* Wed Mar 30 2022 abriel@suse.com
- Adaption to new go compiler behavior regarding test and build
  (bsc#1197697)
* Mon Feb 12 2018 hguo@suse.com
- Upgrade to upstream version 2.0.1 to improve visibility of HANA
  related firewall services in firewalld configuration tool.
  (bsc#1080597)
* Mon Jan 29 2018 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 18 2017 hguo@suse.com
- Upgrade to upstream version 2.0 to work with firewalld in SLES 15.
* Thu Oct  6 2016 hguo@suse.com
- Merge HANA firewall rules into an existing "customrules" script
  if it is present.
- Bump version to 1.1.4 (bsc#1002744);
* Fri Aug  5 2016 hguo@suse.com
- Add several more TCP ports that are vital to HA operation into
  firewall service definition file.
  Bump version to 1.1.3 (bsc#992376)
* Wed Aug  3 2016 hguo@suse.com
- Fix typo and incorrectly assigned default value in sysconfig file.
  Bump version to 1.1.2. (bsc#991919)
* Fri Jun  3 2016 hguo@suse.com
- Improve prompts in create_new_service.
- Relax file permissions in hana-firewall.d directory.
- Fix result file location for create_new_service.
- fate#320564 fate#320376
* Thu Nov  5 2015 hguo@suse.com
- Add missing changelog macro in spec file.
* Fri Oct 23 2015 hguo@suse.com
- Fully integrate with SUSE firewall.
* Wed Oct 21 2015 hguo@suse.com
- Remove unnecesary defaults from sysconfig.
* Tue Oct  6 2015 varkoly@suse.com
- Fix names in sysconfig file
* Fri Oct  2 2015 hguo@suse.com
- Bring HANA-Firewall out of technical preview with feature
  enhancements and major code clean-up.
* Thu Mar 12 2015 varkoly@suse.com
- Initial Version of HANA-Firewall
